@@ -564,22 +564,17 @@ impl Client {
                             if !self.data.alias_to_room.contains_key(&alias) {
                                 self.data
                                     .alias_to_room
-                                    .insert(alias.clone(), room_id.clone())
-                                    .unwrap();
+                                    .insert(alias.clone(), room_id.clone());
                             }
                             if !self.data.room_to_aliases.contains_key(room_id) {
                                 self.data
                                     .room_to_aliases
-                                    .insert(room_id.clone(), vec![alias])
-                                    .unwrap();
+                                    .insert(room_id.clone(), vec![alias]);
                             } else {
                                 if !self.data.room_to_aliases[room_id].contains(&alias) {
                                     let mut current = self.data.room_to_aliases[room_id].clone();
                                     current.push(alias.clone());
-                                    self.data
-                                        .room_to_aliases
-                                        .insert(room_id.clone(), current)
-                                        .unwrap();
+                                    self.data.room_to_aliases.insert(room_id.clone(), current);
                                 }
                             }
                         }
